==> RsSmw-4.90.49.53-py3-none-any.whl: RsSmw/Implementations/Source/Bb/Nfc/Cblock/Pselection.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pselection:
	"""Pselection commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pselection", core, parent)

	def set(self, pselection: enums.NfcPcktSelect, commandBlock=repcap.CommandBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:PSELection \n
		Snippet: driver.source.bb.nfc.cblock.pselection.set(pselection = enums.NfcPcktSelect.PCK1, commandBlock = repcap.CommandBlock.Default) \n
		Selects if the first or second packet of the SECTOR_SELECT command is transmitted. \n
			:param pselection: PCK1| PCK2
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
		"""
		param = Conversions.enum_scalar_to_str(pselection, enums.NfcPcktSelect)
		commandBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:PSELection {param}')

	# noinspection PyTypeChecker
	def get(self, commandBlock=repcap.CommandBlock.Default) -> enums.NfcPcktSelect:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:PSELection \n
		Snippet: value: enums.NfcPcktSelect = driver.source.bb.nfc.cblock.pselection.get(commandBlock = repcap.CommandBlock.Default) \n
		Selects if the first or second packet of the SECTOR_SELECT command is transmitted. \n
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: pselection: PCK1| PCK2"""
		commandBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:PSELection?')
		return Conversions.str_to_scalar_enum(response, enums.NfcPcktSelect)

==> RsSmw-5.0.44.58-py3-none-any.whl: RsSmw/Implementations/Source/Bb/Nfc/Cblock/Pselection.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pselection:
	"""Pselection commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pselection", core, parent)

	def set(self, pselection: enums.NfcPcktSelect, commandBlock=repcap.CommandBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:PSELection \n
		Snippet: driver.source.bb.nfc.cblock.pselection.set(pselection = enums.NfcPcktSelect.PCK1, commandBlock = repcap.CommandBlock.Default) \n
		Selects if the first or second packet of the SECTOR_SELECT command is transmitted. \n
			:param pselection: PCK1| PCK2
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
		"""
		param = Conversions.enum_scalar_to_str(pselection, enums.NfcPcktSelect)
		commandBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:PSELection {param}')

	# noinspection PyTypeChecker
	def get(self, commandBlock=repcap.CommandBlock.Default) -> enums.NfcPcktSelect:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:PSELection \n
		Snippet: value: enums.NfcPcktSelect = driver.source.bb.nfc.cblock.pselection.get(commandBlock = repcap.CommandBlock.Default) \n
		Selects if the first or second packet of the SECTOR_SELECT command is transmitted. \n
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: pselection: PCK1| PCK2"""
		commandBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:PSELection?')
		return Conversions.str_to_scalar_enum(response, enums.NfcPcktSelect)
